@@ -5,7 +5,7 @@ Daemon class
 
 This class is the main core of the daemon, this serves a basic dbus module to control the main bit of the daemon
 """
-__version__ = '3.9.0'
+__version__ = '3.11.0'
 
 import configparser
 import logging
@@ -90,10 +90,13 @@ class RazerDaemon(DBusService):
         self._persistence.status = {"changed": False}
         self.read_persistence(persistence_file)
 
-        # Check for plugdev group
-        if not self._check_plugdev_group():
-            self.logger.critical("User is not a member of the plugdev group")
-            self.logger.critical("Please run the command 'sudo gpasswd -a $USER plugdev' and then reboot!")
+        # map of vid+pid to counter for serial numbers for unknown devices
+        self._unknown_serial_counter: dict[tuple[int, int], int] = {}
+
+        # Check for openrazer group
+        if not self._check_openrazer_group():
+            self.logger.critical("User is not a member of the openrazer group")
+            self.logger.critical("Please run the command 'sudo gpasswd -a $USER openrazer' and then reboot!")
             sys.exit(1)
 
         # Setup DBus to use gobject main loop
@@ -182,9 +185,9 @@ class RazerDaemon(DBusService):
 
         return logger
 
-    def _check_plugdev_group(self):
+    def _check_openrazer_group(self):
         """
-        Check if the user is a member of the plugdev group. For the root
+        Check if the user is a member of the openrazer group. For the root
         user, this always returns True
 
         :rtype: bool
@@ -193,7 +196,7 @@ class RazerDaemon(DBusService):
             return True
 
         try:
-            return grp.getgrnam('plugdev').gr_gid in os.getgroups()
+            return grp.getgrnam('openrazer').gr_gid in os.getgroups()
         except KeyError:
             pass
 
@@ -485,14 +488,15 @@ class RazerDaemon(DBusService):
                     file_group_id = os.stat(test_file).st_gid
                     file_group_name = grp.getgrgid(file_group_id)[0]
 
-                    if os.getgid() != file_group_id and file_group_name != 'plugdev':
-                        self.logger.critical("Could not access {0}/device_type, file is not owned by plugdev".format(sys_path))
+                    if os.getgid() != file_group_id and file_group_name != 'openrazer':
+                        self.logger.critical("Could not access {0}/device_type, file is not owned by openrazer".format(sys_path))
                         break
 
                     razer_device = device_class(device_path=sys_path, device_number=device_number, config=self._config,
                                                 persistence=self._persistence, testing=self._test_dir is not None,
                                                 additional_interfaces=sorted(additional_interfaces),
-                                                additional_methods=[])
+                                                additional_methods=[],
+                                                unknown_serial_counter=self._unknown_serial_counter)
 
                     # Wireless devices sometimes don't listen
                     count = 0
@@ -530,7 +534,8 @@ class RazerDaemon(DBusService):
                 self.logger.info('Found valid device.%d: %s', device_number, sys_name)
                 razer_device = device_class(device_path=sys_path, device_number=device_number, config=self._config,
                                             persistence=self._persistence, testing=self._test_dir is not None,
-                                            additional_interfaces=None, additional_methods=[])
+                                            additional_interfaces=None, additional_methods=[],
+                                            unknown_serial_counter=self._unknown_serial_counter)
 
                 # Its a udev event so currently the device hasn't been chmodded yet
                 time.sleep(0.2)
