@@ -1008,6 +1008,41 @@ class RazerNagaProWireless(RazerNagaProWired):
     METHODS = RazerNagaProWired.METHODS + ['set_charge_effect', 'set_charge_colour']
 
 
+class RazerNagaV2ProWired(__RazerDeviceBrightnessSuspend):
+    """
+    Class for the Razer Naga V2 Pro (Wired)
+    """
+    USB_VID = 0x1532
+    USB_PID = 0x00A7
+    HAS_MATRIX = True
+    WAVE_DIRS = (1, 2)
+    MATRIX_DIMS = [1, 3]
+
+    DEDICATED_MACRO_KEYS = True
+    METHODS = ['get_device_type_mouse', 'max_dpi', 'get_dpi_xy', 'set_dpi_xy', 'get_poll_rate', 'set_poll_rate', 'get_dpi_stages', 'set_dpi_stages',
+               # Battery
+               'get_battery', 'is_charging', 'get_idle_time', 'set_idle_time', 'get_low_battery_threshold', 'set_low_battery_threshold',
+               # Logo
+               'get_logo_brightness', 'set_logo_brightness',
+               'set_logo_wave', 'set_logo_static', 'set_logo_spectrum', 'set_logo_none', 'set_logo_reactive', 'set_logo_breath_random', 'set_logo_breath_single', 'set_logo_breath_dual',
+               # Thumbgrid
+               'set_static_effect', 'set_spectrum_effect', 'set_reactive_effect', 'set_none_effect', 'set_breath_random_effect', 'set_breath_single_effect', 'set_breath_dual_effect',
+               # Custom frame
+               'set_custom_effect', 'set_key_row']
+
+    DPI_MAX = 30000
+
+    DEVICE_IMAGE = "https://dl.razerzone.com/src2/6292/6292-1-en-v1.png"
+
+
+class RazerNagaV2ProWireless(RazerNagaV2ProWired):
+    """
+    Class for the Razer Naga V2 Pro (Wireless)
+    """
+    USB_PID = 0x00A8
+    METHODS = RazerNagaV2ProWired.METHODS + ['set_charge_effect', 'set_charge_colour']
+
+
 class RazerDeathAdder1800(__RazerDevice):
     """
     Class for the Razer DeathAdder 1800
@@ -1596,7 +1631,7 @@ class RazerDeathAdderV3ProWired(__RazerDevice):
 
     DEVICE_IMAGE = "https://dl.razerzone.com/src/6130/6130-1-en-v2.png"
 
-    DPI_MAX = 30000
+    DPI_MAX = 35000
 
 
 class RazerDeathAdderV3ProWireless(RazerDeathAdderV3ProWired):
@@ -1665,6 +1700,124 @@ class RazerBasiliskV3ProWireless(RazerBasiliskV3ProWired):
     USB_PID = 0x00AB
 
 
+class RazerBasiliskV3Pro35KWired(__RazerDevice):
+    """
+    Class for the Razer Basilisk V3 Pro 35K (Wired)
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*Razer_Basilisk_V3_Pro_35K_000000000000-if0(1|2)-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x00CC
+    HAS_MATRIX = True
+    MATRIX_DIMS = [1, 13]
+    METHODS = ['get_device_type_mouse',
+               'max_dpi', 'get_dpi_xy', 'set_dpi_xy', 'get_dpi_stages', 'set_dpi_stages',
+               'get_poll_rate', 'set_poll_rate',
+               'get_brightness', 'set_brightness',
+               'get_logo_brightness', 'set_logo_brightness',
+               'get_scroll_brightness', 'set_scroll_brightness',
+               # Scroll wheel controls
+               'get_scroll_mode', 'set_scroll_mode',
+               'get_scroll_acceleration', 'set_scroll_acceleration',
+               'get_scroll_smart_reel', 'set_scroll_smart_reel',
+               # All LEDs (partial support)
+               'set_static_effect', 'set_wave_effect', 'set_spectrum_effect', 'set_none_effect',
+               # Logo (partial support)
+               'set_logo_wave', 'set_logo_static', 'set_logo_spectrum', 'set_logo_none',
+               # Scroll wheel (partial support)
+               'set_scroll_wave', 'set_scroll_static', 'set_scroll_spectrum', 'set_scroll_none',
+               # Can set custom matrix effects
+               'set_custom_effect', 'set_key_row',
+               # Battery
+               'get_battery', 'is_charging', 'get_idle_time', 'set_idle_time', 'get_low_battery_threshold', 'set_low_battery_threshold']
+
+    DEVICE_IMAGE = "https://dl.razerzone.com/src2/14676/14676-1-en-v1.png"
+
+    DPI_MAX = 35000
+
+
+class RazerBasiliskV3Pro35KWireless(RazerBasiliskV3Pro35KWired):
+    """
+    Class for the Razer Basilisk V3 Pro 35K (Wireless)
+    """
+
+    USB_PID = 0x00CD
+
+
+class RazerBasiliskV3Pro35KPhantomGreenEditionWired(__RazerDevice):
+    """
+    Class for the Razer Basilisk V3 Pro 35K Phantom Green Edition (Wired)
+    """
+    USB_VID = 0x1532
+    USB_PID = 0x00D6
+    HAS_MATRIX = True
+    MATRIX_DIMS = [1, 12]
+    METHODS = ['get_device_type_mouse',
+               'max_dpi', 'get_dpi_xy', 'set_dpi_xy', 'get_dpi_stages', 'set_dpi_stages',
+               'get_poll_rate', 'set_poll_rate',
+               'get_brightness', 'set_brightness',
+               'get_scroll_brightness', 'set_scroll_brightness',
+               # Scroll wheel controls
+               'get_scroll_mode', 'set_scroll_mode',
+               'get_scroll_acceleration', 'set_scroll_acceleration',
+               'get_scroll_smart_reel', 'set_scroll_smart_reel',
+               # All LEDs (partial support)
+               'set_static_effect', 'set_wave_effect', 'set_spectrum_effect', 'set_none_effect',
+               # Scroll wheel (partial support)
+               'set_scroll_wave', 'set_scroll_static', 'set_scroll_spectrum', 'set_scroll_none',
+               # Can set custom matrix effects
+               'set_custom_effect', 'set_key_row',
+               # Battery
+               'get_battery', 'is_charging', 'get_idle_time', 'set_idle_time', 'get_low_battery_threshold', 'set_low_battery_threshold']
+
+    DEVICE_IMAGE = "https://medias-p1.phoenix.razer.com/sys-master-phoenix-images-container/haa/h04/9917236707358/250605-basilisk-v3-pro-35k-phantom-green-1500x1000-4.jpg"
+
+    DPI_MAX = 35000
+
+
+class RazerBasiliskV3Pro35KPhantomGreenEditionWireless(RazerBasiliskV3Pro35KPhantomGreenEditionWired):
+    """
+    Class for the Razer Basilisk V3 Pro 35K Phantom Green Edition (Wireless)
+    """
+
+    USB_PID = 0x00D7
+
+
+class RazerBasiliskV3_35K(__RazerDevice):
+    """
+    Class for the Razer Basilisk V3 35K
+    """
+
+    EVENT_FILE_REGEX = re.compile(r'.*Razer_Basilisk_V3_35K-if0(1|2)-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x00CB
+    HAS_MATRIX = True
+    MATRIX_DIMS = [1, 13]
+    METHODS = ['get_device_type_mouse',
+               'max_dpi', 'get_dpi_xy', 'set_dpi_xy', 'get_dpi_stages', 'set_dpi_stages',
+               'get_poll_rate', 'set_poll_rate',
+               'get_brightness', 'set_brightness',
+               'get_logo_brightness', 'set_logo_brightness',
+               'get_scroll_brightness', 'set_scroll_brightness',
+               # Scroll wheel controls
+               'get_scroll_mode', 'set_scroll_mode',
+               'get_scroll_acceleration', 'set_scroll_acceleration',
+               'get_scroll_smart_reel', 'set_scroll_smart_reel',
+               # All LEDs (partial support)
+               'set_static_effect', 'set_wave_effect', 'set_spectrum_effect', 'set_none_effect',
+               # Logo (partial support)
+               'set_logo_wave', 'set_logo_static', 'set_logo_spectrum', 'set_logo_none',
+               # Scroll wheel (partial support)
+               'set_scroll_wave', 'set_scroll_static', 'set_scroll_spectrum', 'set_scroll_none',
+               # Can set custom matrix effects
+               'set_custom_effect', 'set_key_row']
+
+    DEVICE_IMAGE = "https://hybrismediaprod.blob.core.windows.net/sys-master-phoenix-images-container/he4/h63/9822107926558/basilisk-v3-35k-2-500x500.png"
+
+    DPI_MAX = 35000
+
+
 class RazerHyperPollingWirelessDongle(__RazerDevice):
     """
     Class for the Razer HyperPolling Wireless Dongle
@@ -1809,10 +1962,36 @@ class RazerBasiliskV3XHyperSpeed(__RazerDevice):
                'set_scroll_wave', 'set_scroll_static', 'set_scroll_spectrum', 'set_scroll_none', 'set_scroll_reactive', 'set_scroll_breath_random', 'set_scroll_breath_single', 'set_scroll_breath_dual']
 
     DEVICE_IMAGE = "https://dl.razerzone.com/src2/9766/9766-1-en-v1.png"
+    DRIVER_MODE = True
 
     DPI_MAX = 18000
 
 
+class RazerDeathAdderV4ProWired(__RazerDevice):
+    """
+    Class for the Razer DeathAdder V4 Pro (Wired)
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*usb-Razer_DeathAdder_V4_Pro_[0-9A-F]+-if0(1|2)-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x00BE
+    METHODS = ['get_device_type_mouse', 'max_dpi', 'get_dpi_xy', 'set_dpi_xy', 'get_dpi_stages', 'set_dpi_stages',
+               'get_poll_rate', 'set_poll_rate', 'get_supported_poll_rates',
+               'get_battery', 'is_charging', 'get_idle_time', 'set_idle_time', 'get_low_battery_threshold', 'set_low_battery_threshold']
+
+    DEVICE_IMAGE = "https://medias-p1.phoenix.razer.com/sys-master-phoenix-images-container/h01/hf3/9926511951902/deathadder-v4-pro-black-500x500.png"
+
+    POLL_RATES = [125, 500, 1000, 2000, 4000, 8000]
+    DPI_MAX = 45000
+
+
+class RazerDeathAdderV4ProWireless(RazerDeathAdderV4ProWired):
+    """
+    Class for the Razer DeathAdder V4 Pro (Wireless)
+    """
+    USB_PID = 0x00BF
+
+
 class RazerViperV3ProWired(__RazerDevice):
     """
     Class for the Razer Viper V3 Pro (Wired)
@@ -1841,3 +2020,85 @@ class RazerViperV3ProWireless(RazerViperV3ProWired):
     METHODS = RazerViperV3ProWired.METHODS + ['set_hyperpolling_wireless_dongle_indicator_led_mode']
 
     POLL_RATES = [125, 500, 1000, 2000, 4000, 8000]
+
+
+class RazerDeathAdderV3HyperSpeedWired(__RazerDevice):
+    """
+    Class for the Razer DeathAdder V3 HyperSpeed (Wired)
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*usb-Razer_Razer_DeathAdder_V3_HyperSpeed_000000000000-if0(1|2)-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x00C4
+    METHODS = ['get_device_type_mouse', 'max_dpi', 'get_dpi_xy', 'set_dpi_xy', 'get_dpi_stages', 'set_dpi_stages',
+               'get_poll_rate', 'set_poll_rate',
+               # Battery
+               'get_battery', 'is_charging', 'get_idle_time', 'set_idle_time', 'get_low_battery_threshold', 'set_low_battery_threshold']
+
+    DEVICE_IMAGE = "https://dl.razerzone.com/src/6124/6124-1-en-v2.png"
+
+    DPI_MAX = 26000
+
+
+class RazerDeathAdderV3HyperSpeedWireless(RazerDeathAdderV3HyperSpeedWired):
+    """
+    Class for the Razer DeathAdder V3 HyperSpeed (Wireless)
+    """
+
+    USB_PID = 0x00C5
+
+
+class RazerProClickV2VerticalEditionWired(__RazerDevice):
+    """
+    Class for the Razer Pro Click V2 Vertical Edition (Wired)
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*usb-Razer_Razer_Pro_Click_V2_Vertical_Edition-if0(1|2)-event-kbd')
+    USB_VID = 0x1532
+    USB_PID = 0x00C7
+    METHODS = ['get_device_type_mouse', 'max_dpi', 'get_dpi_xy', 'set_dpi_xy',
+               'get_dpi_stages', 'set_dpi_stages',
+               'get_poll_rate', 'set_poll_rate', 'get_supported_poll_rates',
+               'get_idle_time', 'set_idle_time',
+               'get_battery', 'is_charging',
+               'get_low_battery_threshold', 'set_low_battery_threshold',
+               'get_brightness', 'set_brightness', 'set_static_effect', 'set_wave_effect', 'set_spectrum_effect', 'set_none_effect']
+    DEVICE_IMAGE = "https://dl.razerzone.com/src2/15010/15010-1-en-v1.png"
+
+    DPI_MAX = 30000
+
+    POLL_RATES = [125, 250, 500, 1000]
+
+
+class RazerProClickV2VerticalEditionWireless(RazerProClickV2VerticalEditionWired):
+    """
+    Class for the Razer Pro Click V2 Vertical Edition (Wireless)
+    """
+    USB_PID = 0x00C8
+
+
+class RazerProClickV2Wired(__RazerDevice):
+    """
+    Class for the Razer Pro Click V2 (Wired)
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*usb-Razer_Razer_Pro_Click_V2-if0(1|2)-event-kbd')
+    USB_VID = 0x1532
+    USB_PID = 0x00D0
+    METHODS = ['get_device_type_mouse', 'max_dpi', 'get_dpi_xy', 'set_dpi_xy',
+               'get_dpi_stages', 'set_dpi_stages',
+               'get_poll_rate', 'set_poll_rate', 'get_supported_poll_rates',
+               'get_idle_time', 'set_idle_time',
+               'get_battery', 'is_charging',
+               'get_low_battery_threshold', 'set_low_battery_threshold',
+               'get_brightness', 'set_brightness', 'set_static_effect', 'set_wave_effect', 'set_spectrum_effect', 'set_none_effect']
+    DEVICE_IMAGE = "https://medias-p1.phoenix.razer.com/sys-master-phoenix-images-container/ha3/h76/9899953717278/pro-click-v2-black-500x500.png"
+
+    DPI_MAX = 30000
+
+    POLL_RATES = [125, 250, 500, 1000]
+
+
+class RazerProClickV2Wireless(RazerProClickV2Wired):
+    """
+    Class for the Razer Pro Click V2 (Wireless)
+    """
+    USB_PID = 0x00D1
